==> haskell-cpphs-1.20.5-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.5
id: cpphs-1.20.5-JtCTdf7c3ZZHWjVqdAT4Bl
key: cpphs-1.20.5-JtCTdf7c3ZZHWjVqdAT4Bl
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: 41e9009eee629facabfc23f951a78fac
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.5
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/cpphs-1.20.5
hs-libraries: HScpphs-1.20.5-JtCTdf7c3ZZHWjVqdAT4Bl
depends:
    base-4.9.1.0 directory-1.3.0.0
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    old-time-1.1.0.3-EZzkBJ4NQxX4hHavrKxgaT
    polyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cpphs-1.20.8-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cpphs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cpphs
version: 1.20.8
id: cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
key: cpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
license: LGPL
copyright: 2004-2017, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
homepage: http://projects.haskell.org/cpphs/
synopsis: A liberalised re-implementation of cpp, the C pre-processor.
description:
    Cpphs is a re-implementation of the C pre-processor that is both
    more compatible with Haskell, and itself written in Haskell so
    that it can be distributed with compilers.
    .
    This version of the C pre-processor is pretty-much
    feature-complete and compatible with traditional (K&R)
    pre-processors.  Additional features include: a plain-text mode;
    an option to unlit literate code files; and an option to turn
    off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules:
    Language.Preprocessor.Cpphs Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
abi: af11361355d802e7c7eb6aa76b806a47
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/cpphs-1.20.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/cpphs-1.20.8
hs-libraries: HScpphs-1.20.8-GyXkmDRyCCk1Z2EfyxKuOh
depends:
    base-4.9.1.0 directory-1.3.0.0
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    old-time-1.1.0.3-EZzkBJ4NQxX4hHavrKxgaT
    polyparse-1.12-2dxp3MdYSYOEcDgRo6TZWF
haddock-interfaces: /usr/share/doc/haskell-cpphs/html/cpphs.haddock
haddock-html: /usr/share/doc/haskell-cpphs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
